# -*- coding: utf-8 -*-
from unittest import TestCase

import namesex_light
import numpy as np

class test_namesex_light(TestCase):
    def test_feat_dict_other_value(self):
        s = namesex_light.namesex_light()
        self.assertTrue("_Other_Value_" in s.feat_dict)

    def test_feat_dict_size(self):
        s = namesex_light.namesex_light()
        self.assertTrue(len(s.feat_dict) > 1000)
    def test_predict(self):
        nsl = namesex_light.namesex_light()
        pred1 = nsl.predict(['民豪', '愛麗', '志明'])
        ans1 = np.array([1, 0, 1])

        self.assertTrue(sum(pred1 == ans1) == len(ans1))



# -*- coding: utf-8 -*-
#import numpy as np
import pkg_resources
import csv


#load data from the csv file
class testdata:
    def __init__(self):
        filename = pkg_resources.resource_filename('namesex', 'data/testdata.csv')
        f = open(filename, 'r', newline='', encoding = 'utf8')
        mydata = csv.DictReader(f)
        sexlist = []
        namelist = []
        for arow in mydata:
            sexlist.append(int(arow['sex'].strip()))
            gname = arow['name'].strip()
            namelist.append(gname)

        self.gname = namelist
        self.sex = sexlist


if __name__ == "__main__":
    import namesex
    testdata = testdata()
    nsl = namesex.namesex()
    pred = nsl.predict(testdata.gname)
    print("The first 5 given names are: {}".format(testdata.gname[0:5]))
    print("    and their sex:          {}".format(testdata.sex[0:5]))
    print("    and their predicted sex:{}".format(pred[0:5]))
    accuracy = np.sum(pred == testdata.sex) / len(pred)
    print(" Prediction accuracy = {}".format(accuracy))
